==> deepin-font-manager_5.9.6.orig.tar.xz: deepin-font-manager-5.9.6/translations/deepin-font-manager_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Все Шрифты</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Системные</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Пользовательские</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Избранные</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активные</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Китайские</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Моноширинные</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 не является семейством шрифтов, если Вы продолжите, все шрифты в нем будут удалены</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 - это семейство шрифтов, если Вы продолжите, все шрифты в нем будут включены</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Отключить</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished">Применить ко всем выбранным семействам шрифтов</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Отменить</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Поврежденный файл</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Эта версия уже установлена</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Системный шрифт</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Шрифты</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 установлены</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 установленный шрифт</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Поврежденный файл</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Этот шрифт не будет доступен для приложений</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Эти шрифты не будут доступны для приложений.</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Другие системные шрифты %1 не могут быть удалены</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Используемый шрифт &quot;%1&quot; нельзя удалить</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Другие системные шрифты %1 и используемый шрифт &quot;%2&quot; не могут быть удалены</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Вы действительно хотите удалить %1 шрифт(ы)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Удаление шрифтов, пожалуйста, подождите...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Проверка Шрифта</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Шрифты не устанавливаются</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Продолжить</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Не позволяй своим мечтам быть мечтами.</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Полное имя</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Пс-Имя</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Торговая марка</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Менеджер Шрифтов</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Менеджер Шрифтов помогает пользователям устанавливать и управлять шрифтами.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Загрузка шрифтов, пожалуйста, подождите...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Шрифт экспортируется на рабочий стол</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 шрифт, экспортированный на рабочий стол</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Не удалось экспортировать 1 шрифт. Недостаточно места на диске.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Не удалось экспортировать %1 шрифт. Недостаточно места на диске.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Добавить шрифт</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Отключить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показать в файловом менеджере</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>отключенный</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Шрифты были отключены</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 используется, поэтому Вы не можете отключить его</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Вы не можете отключить системные шрифты и используемые шрифты</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Установить Шрифт</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Проверка...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Поврежденный файл</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Установлен</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Не Установлен</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Установить Шрифт</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Нет результатов поиска</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Нет шрифтов</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показать сочетания клавиш</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Страница вверх</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Страница вниз</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Добавить шрифт</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Информация о шрифте</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Введите текст для просмотра</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.13.orig.tar.xz: deepin-font-manager-5.9.13/translations/deepin-font-manager_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Все Шрифты</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Системные</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Пользовательские</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Избранные</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активные</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Китайские</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Моноширинные</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 не является семейством шрифтов, если Вы продолжите, все шрифты в нем будут удалены</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 - это семейство шрифтов, если Вы продолжите, все шрифты в нем будут включены</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 - это семейство шрифтов; если вы продолжите, все шрифты в нем будут отключены</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Отключить</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Применить ко всем выбранным семействам шрифтов</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Поврежденный файл</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Эта версия уже установлена</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Системный шрифт</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 установлены</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 установленный шрифт</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Не удалось установить шрифты % 1. Недостаточно места на диске.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Этот шрифт не будет доступен для приложений</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Эти шрифты не будут доступны для приложений.</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Другие системные шрифты %1 не могут быть удалены</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Используемый шрифт &quot;%1&quot; нельзя удалить</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Другие системные шрифты %1 и используемый шрифт &quot;%2&quot; не могут быть удалены</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Вы действительно хотите удалить %1 шрифт(ы)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Удаление шрифтов, пожалуйста, подождите...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Проверка Шрифта</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Шрифты не устанавливаются</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Продолжить</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Полное имя</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Пс-Имя</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Торговая марка</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Менеджер Шрифтов</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Менеджер Шрифтов помогает пользователям устанавливать и управлять шрифтами.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Загрузка шрифтов, пожалуйста, подождите...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Шрифт экспортируется на рабочий стол</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 шрифт, экспортированный на рабочий стол</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Не удалось экспортировать 1 шрифт. Недостаточно места на диске.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Не удалось экспортировать %1 шрифт. Недостаточно места на диске.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Добавить шрифт</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Отключить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показать в файловом менеджере</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>отключенный</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Шрифты были отключены</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 используется, поэтому Вы не можете отключить его</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Вы не можете отключить системные шрифты и используемые шрифты</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Нельзя отключить системные шрифты</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Установить Шрифт</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Проверка...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Поврежденный файл</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Установлен</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Не Установлен</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Установить Шрифт</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Нет результатов поиска</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Нет шрифтов</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показать сочетания клавиш</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Страница вверх</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Страница вниз</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Добавить шрифт</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Информация о шрифте</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Введите текст для просмотра</translation>
    </message>
</context>
</TS>
